from setuptools import setup

setup(
   name='yacine_47_rocket',
   version='1.0.0',
   author='Yassine DRISS',
   author_email='y.driss@esi-sba.dz',
   packages=['yacine_47_rocket'],
   url='http://pypi.python.org/pypi/yacine_47_rocket/',
   license='LICENSE.txt',
   description='An awesome package that does something with rockets and shuttles',
   long_description=open('README.md').read(),
   long_description_content_type="text/markdown",
   install_requires=[]
)